@@ -12,7 +12,7 @@ def go(ohlc, key, window=2):
     volume_data, ohlc = t.volume(ohlc, key)
     #obv_data, ohlc = t.on_balance_volume(ohlc, 5, key)
 
-    data = div_data + bollinger_data + macd_data + ma_data + ema_data + rsi_data
+    data = div_data + bollinger_data + macd_data + ma_data + ema_data + rsi_data + volume_data
 
     return data, ohlc
 
